@@ -40,7 +40,7 @@ import pyflakes.messages
 import pyflakes.reporter
 
 
-__version__ = "2.1.0"
+__version__ = "2.1.1"
 
 
 _LOGGER = logging.getLogger("autoflake")
@@ -1194,11 +1194,7 @@ def merge_configuration_file(flag_args):
 
     if "config_file" in flag_args:
         config_file = pathlib.Path(flag_args["config_file"]).resolve()
-
-        if config_file.suffix == ".toml":
-            config = process_pyproject_toml(config_file)
-        else:
-            config = process_config_file(config_file)
+        config = process_config_file(config_file)
 
         if not config:
             _LOGGER.error(
