@@ -3385,32 +3385,6 @@ class ConfigFileTest(unittest.TestCase):
                 check=True,
             )
 
-    def test_config_option_toml(self):
-        with temporary_file(
-            suffix=".toml",
-            contents=(
-                "[tool.autoflake]\n"
-                "check = true\n"
-                'exclude = [\n  "build",\n  ".venv",\n]'
-            ),
-        ) as temp_config:
-            self.create_file("test_me.py")
-            files = [self.effective_path("test_me.py")]
-
-            args, success = autoflake.merge_configuration_file(
-                {
-                    "files": files,
-                    "config_file": temp_config,
-                },
-            )
-            assert success is True
-            assert args == self.with_defaults(
-                files=files,
-                config_file=temp_config,
-                check=True,
-                exclude="build,.venv",
-            )
-
     def test_load_false(self):
         self.create_file("test_me.py")
         self.create_file(
